# Deep Glue

<img src="https://raw.githubusercontent.com/EricThomson/deepglue/main/docs/images/deep_glue_logo.png" alt="deepglue logo" align="right" width="180">

Utilities for pytorch-based deep learning projects. Keeping the useful stuff together in one place.

- `pip install deepglue`
- `import deepglue as dg`
- Read the docs at https://deepglue.readthedocs.io/en/latest/ 
- [Roadmap](https://github.com/EricThomson/deepglue/issues/1) :world_map:



